# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetQueryQuickPicksResult',
    'AwaitableGetQueryQuickPicksResult',
    'get_query_quick_picks',
    'get_query_quick_picks_output',
]

@pulumi.output_type
class GetQueryQuickPicksResult:
    """
    A collection of values returned by getQueryQuickPicks.
    """
    def __init__(__self__, apm_domain_id=None, filters=None, id=None, quick_picks=None):
        if apm_domain_id and not isinstance(apm_domain_id, str):
            raise TypeError("Expected argument 'apm_domain_id' to be a str")
        pulumi.set(__self__, "apm_domain_id", apm_domain_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if quick_picks and not isinstance(quick_picks, list):
            raise TypeError("Expected argument 'quick_picks' to be a list")
        pulumi.set(__self__, "quick_picks", quick_picks)

    @property
    @pulumi.getter(name="apmDomainId")
    def apm_domain_id(self) -> str:
        return pulumi.get(self, "apm_domain_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetQueryQuickPicksFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="quickPicks")
    def quick_picks(self) -> Sequence['outputs.GetQueryQuickPicksQuickPickResult']:
        """
        The list of quick_picks.
        """
        return pulumi.get(self, "quick_picks")


class AwaitableGetQueryQuickPicksResult(GetQueryQuickPicksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQueryQuickPicksResult(
            apm_domain_id=self.apm_domain_id,
            filters=self.filters,
            id=self.id,
            quick_picks=self.quick_picks)


def get_query_quick_picks(apm_domain_id: Optional[str] = None,
                          filters: Optional[Sequence[pulumi.InputType['GetQueryQuickPicksFilterArgs']]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetQueryQuickPicksResult:
    """
    This data source provides the list of Query Quick Picks in Oracle Cloud Infrastructure Apm Traces service.

    Returns a list of predefined Quick Pick queries intended to assist the user
    to choose a query to run.  There is no sorting applied on the results.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_query_quick_picks = oci.ApmTraces.get_query_quick_picks(apm_domain_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str apm_domain_id: The APM Domain ID the request is intended for.
    """
    __args__ = dict()
    __args__['apmDomainId'] = apm_domain_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ApmTraces/getQueryQuickPicks:getQueryQuickPicks', __args__, opts=opts, typ=GetQueryQuickPicksResult).value

    return AwaitableGetQueryQuickPicksResult(
        apm_domain_id=__ret__.apm_domain_id,
        filters=__ret__.filters,
        id=__ret__.id,
        quick_picks=__ret__.quick_picks)


@_utilities.lift_output_func(get_query_quick_picks)
def get_query_quick_picks_output(apm_domain_id: Optional[pulumi.Input[str]] = None,
                                 filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetQueryQuickPicksFilterArgs']]]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetQueryQuickPicksResult]:
    """
    This data source provides the list of Query Quick Picks in Oracle Cloud Infrastructure Apm Traces service.

    Returns a list of predefined Quick Pick queries intended to assist the user
    to choose a query to run.  There is no sorting applied on the results.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_query_quick_picks = oci.ApmTraces.get_query_quick_picks(apm_domain_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str apm_domain_id: The APM Domain ID the request is intended for.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetServiceCatalogAssociationsResult',
    'AwaitableGetServiceCatalogAssociationsResult',
    'get_service_catalog_associations',
    'get_service_catalog_associations_output',
]

@pulumi.output_type
class GetServiceCatalogAssociationsResult:
    """
    A collection of values returned by getServiceCatalogAssociations.
    """
    def __init__(__self__, entity_id=None, entity_type=None, filters=None, id=None, service_catalog_association_collections=None, service_catalog_association_id=None, service_catalog_id=None):
        if entity_id and not isinstance(entity_id, str):
            raise TypeError("Expected argument 'entity_id' to be a str")
        pulumi.set(__self__, "entity_id", entity_id)
        if entity_type and not isinstance(entity_type, str):
            raise TypeError("Expected argument 'entity_type' to be a str")
        pulumi.set(__self__, "entity_type", entity_type)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_catalog_association_collections and not isinstance(service_catalog_association_collections, list):
            raise TypeError("Expected argument 'service_catalog_association_collections' to be a list")
        pulumi.set(__self__, "service_catalog_association_collections", service_catalog_association_collections)
        if service_catalog_association_id and not isinstance(service_catalog_association_id, str):
            raise TypeError("Expected argument 'service_catalog_association_id' to be a str")
        pulumi.set(__self__, "service_catalog_association_id", service_catalog_association_id)
        if service_catalog_id and not isinstance(service_catalog_id, str):
            raise TypeError("Expected argument 'service_catalog_id' to be a str")
        pulumi.set(__self__, "service_catalog_id", service_catalog_id)

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[str]:
        """
        Identifier of the entity being associated with service catalog.
        """
        return pulumi.get(self, "entity_id")

    @property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> Optional[str]:
        """
        The type of the entity that is associated with the service catalog.
        """
        return pulumi.get(self, "entity_type")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetServiceCatalogAssociationsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceCatalogAssociationCollections")
    def service_catalog_association_collections(self) -> Sequence['outputs.GetServiceCatalogAssociationsServiceCatalogAssociationCollectionResult']:
        """
        The list of service_catalog_association_collection.
        """
        return pulumi.get(self, "service_catalog_association_collections")

    @property
    @pulumi.getter(name="serviceCatalogAssociationId")
    def service_catalog_association_id(self) -> Optional[str]:
        return pulumi.get(self, "service_catalog_association_id")

    @property
    @pulumi.getter(name="serviceCatalogId")
    def service_catalog_id(self) -> Optional[str]:
        """
        Identifier of the service catalog.
        """
        return pulumi.get(self, "service_catalog_id")


class AwaitableGetServiceCatalogAssociationsResult(GetServiceCatalogAssociationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceCatalogAssociationsResult(
            entity_id=self.entity_id,
            entity_type=self.entity_type,
            filters=self.filters,
            id=self.id,
            service_catalog_association_collections=self.service_catalog_association_collections,
            service_catalog_association_id=self.service_catalog_association_id,
            service_catalog_id=self.service_catalog_id)


def get_service_catalog_associations(entity_id: Optional[str] = None,
                                     entity_type: Optional[str] = None,
                                     filters: Optional[Sequence[pulumi.InputType['GetServiceCatalogAssociationsFilterArgs']]] = None,
                                     service_catalog_association_id: Optional[str] = None,
                                     service_catalog_id: Optional[str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceCatalogAssociationsResult:
    """
    This data source provides the list of Service Catalog Associations in Oracle Cloud Infrastructure Service Catalog service.

    Lists all the resource associations for a specific service catalog.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_service_catalog_associations = oci.ServiceCatalog.get_service_catalog_associations(entity_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        entity_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        service_catalog_association_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        service_catalog_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str entity_id: The unique identifier of the entity associated with service catalog.
    :param str entity_type: The type of the application in the service catalog.
    :param str service_catalog_association_id: The unique identifier for the service catalog association.
    :param str service_catalog_id: The unique identifier for the service catalog.
    """
    __args__ = dict()
    __args__['entityId'] = entity_id
    __args__['entityType'] = entity_type
    __args__['filters'] = filters
    __args__['serviceCatalogAssociationId'] = service_catalog_association_id
    __args__['serviceCatalogId'] = service_catalog_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ServiceCatalog/getServiceCatalogAssociations:getServiceCatalogAssociations', __args__, opts=opts, typ=GetServiceCatalogAssociationsResult).value

    return AwaitableGetServiceCatalogAssociationsResult(
        entity_id=__ret__.entity_id,
        entity_type=__ret__.entity_type,
        filters=__ret__.filters,
        id=__ret__.id,
        service_catalog_association_collections=__ret__.service_catalog_association_collections,
        service_catalog_association_id=__ret__.service_catalog_association_id,
        service_catalog_id=__ret__.service_catalog_id)


@_utilities.lift_output_func(get_service_catalog_associations)
def get_service_catalog_associations_output(entity_id: Optional[pulumi.Input[Optional[str]]] = None,
                                            entity_type: Optional[pulumi.Input[Optional[str]]] = None,
                                            filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetServiceCatalogAssociationsFilterArgs']]]]] = None,
                                            service_catalog_association_id: Optional[pulumi.Input[Optional[str]]] = None,
                                            service_catalog_id: Optional[pulumi.Input[Optional[str]]] = None,
                                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServiceCatalogAssociationsResult]:
    """
    This data source provides the list of Service Catalog Associations in Oracle Cloud Infrastructure Service Catalog service.

    Lists all the resource associations for a specific service catalog.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_service_catalog_associations = oci.ServiceCatalog.get_service_catalog_associations(entity_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        entity_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        service_catalog_association_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        service_catalog_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str entity_id: The unique identifier of the entity associated with service catalog.
    :param str entity_type: The type of the application in the service catalog.
    :param str service_catalog_association_id: The unique identifier for the service catalog association.
    :param str service_catalog_id: The unique identifier for the service catalog.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CloudDatabaseManagementArgs', 'CloudDatabaseManagement']

@pulumi.input_type
class CloudDatabaseManagementArgs:
    def __init__(__self__, *,
                 credentialdetails: pulumi.Input['CloudDatabaseManagementCredentialdetailsArgs'],
                 database_id: pulumi.Input[str],
                 enable_management: pulumi.Input[bool],
                 management_type: pulumi.Input[str],
                 private_end_point_id: pulumi.Input[str],
                 service_name: pulumi.Input[str],
                 port: Optional[pulumi.Input[int]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 ssl_secret_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a CloudDatabaseManagement resource.
        :param pulumi.Input[str] database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[bool] enable_management: (Updatable) Use this flag to enable/disable database management
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] management_type: (Updatable) Specifies database management type
               enum:
        :param pulumi.Input[str] private_end_point_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        :param pulumi.Input[str] service_name: The name of the Oracle Database service that will be used to connect to the database.
        :param pulumi.Input[int] port: The port used to connect to the database.
        :param pulumi.Input[str] protocol: Protocol used by the database connection.
        :param pulumi.Input[str] role: The role of the user that will be connecting to the database.
        :param pulumi.Input[str] ssl_secret_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        pulumi.set(__self__, "credentialdetails", credentialdetails)
        pulumi.set(__self__, "database_id", database_id)
        pulumi.set(__self__, "enable_management", enable_management)
        pulumi.set(__self__, "management_type", management_type)
        pulumi.set(__self__, "private_end_point_id", private_end_point_id)
        pulumi.set(__self__, "service_name", service_name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if ssl_secret_id is not None:
            pulumi.set(__self__, "ssl_secret_id", ssl_secret_id)

    @property
    @pulumi.getter
    def credentialdetails(self) -> pulumi.Input['CloudDatabaseManagementCredentialdetailsArgs']:
        return pulumi.get(self, "credentialdetails")

    @credentialdetails.setter
    def credentialdetails(self, value: pulumi.Input['CloudDatabaseManagementCredentialdetailsArgs']):
        pulumi.set(self, "credentialdetails", value)

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> pulumi.Input[str]:
        """
        The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "database_id")

    @database_id.setter
    def database_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "database_id", value)

    @property
    @pulumi.getter(name="enableManagement")
    def enable_management(self) -> pulumi.Input[bool]:
        """
        (Updatable) Use this flag to enable/disable database management

        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "enable_management")

    @enable_management.setter
    def enable_management(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enable_management", value)

    @property
    @pulumi.getter(name="managementType")
    def management_type(self) -> pulumi.Input[str]:
        """
        (Updatable) Specifies database management type
        enum:
        """
        return pulumi.get(self, "management_type")

    @management_type.setter
    def management_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "management_type", value)

    @property
    @pulumi.getter(name="privateEndPointId")
    def private_end_point_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        """
        return pulumi.get(self, "private_end_point_id")

    @private_end_point_id.setter
    def private_end_point_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "private_end_point_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[str]:
        """
        The name of the Oracle Database service that will be used to connect to the database.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The port used to connect to the database.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Protocol used by the database connection.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The role of the user that will be connecting to the database.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="sslSecretId")
    def ssl_secret_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        return pulumi.get(self, "ssl_secret_id")

    @ssl_secret_id.setter
    def ssl_secret_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ssl_secret_id", value)


@pulumi.input_type
class _CloudDatabaseManagementState:
    def __init__(__self__, *,
                 credentialdetails: Optional[pulumi.Input['CloudDatabaseManagementCredentialdetailsArgs']] = None,
                 database_id: Optional[pulumi.Input[str]] = None,
                 enable_management: Optional[pulumi.Input[bool]] = None,
                 management_type: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 private_end_point_id: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 ssl_secret_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CloudDatabaseManagement resources.
        :param pulumi.Input[str] database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[bool] enable_management: (Updatable) Use this flag to enable/disable database management
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] management_type: (Updatable) Specifies database management type
               enum:
        :param pulumi.Input[int] port: The port used to connect to the database.
        :param pulumi.Input[str] private_end_point_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        :param pulumi.Input[str] protocol: Protocol used by the database connection.
        :param pulumi.Input[str] role: The role of the user that will be connecting to the database.
        :param pulumi.Input[str] service_name: The name of the Oracle Database service that will be used to connect to the database.
        :param pulumi.Input[str] ssl_secret_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        if credentialdetails is not None:
            pulumi.set(__self__, "credentialdetails", credentialdetails)
        if database_id is not None:
            pulumi.set(__self__, "database_id", database_id)
        if enable_management is not None:
            pulumi.set(__self__, "enable_management", enable_management)
        if management_type is not None:
            pulumi.set(__self__, "management_type", management_type)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if private_end_point_id is not None:
            pulumi.set(__self__, "private_end_point_id", private_end_point_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if ssl_secret_id is not None:
            pulumi.set(__self__, "ssl_secret_id", ssl_secret_id)

    @property
    @pulumi.getter
    def credentialdetails(self) -> Optional[pulumi.Input['CloudDatabaseManagementCredentialdetailsArgs']]:
        return pulumi.get(self, "credentialdetails")

    @credentialdetails.setter
    def credentialdetails(self, value: Optional[pulumi.Input['CloudDatabaseManagementCredentialdetailsArgs']]):
        pulumi.set(self, "credentialdetails", value)

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> Optional[pulumi.Input[str]]:
        """
        The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "database_id")

    @database_id.setter
    def database_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_id", value)

    @property
    @pulumi.getter(name="enableManagement")
    def enable_management(self) -> Optional[pulumi.Input[bool]]:
        """
        (Updatable) Use this flag to enable/disable database management

        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "enable_management")

    @enable_management.setter
    def enable_management(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_management", value)

    @property
    @pulumi.getter(name="managementType")
    def management_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Specifies database management type
        enum:
        """
        return pulumi.get(self, "management_type")

    @management_type.setter
    def management_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "management_type", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The port used to connect to the database.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="privateEndPointId")
    def private_end_point_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        """
        return pulumi.get(self, "private_end_point_id")

    @private_end_point_id.setter
    def private_end_point_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_end_point_id", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Protocol used by the database connection.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The role of the user that will be connecting to the database.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Oracle Database service that will be used to connect to the database.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="sslSecretId")
    def ssl_secret_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        return pulumi.get(self, "ssl_secret_id")

    @ssl_secret_id.setter
    def ssl_secret_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ssl_secret_id", value)


class CloudDatabaseManagement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credentialdetails: Optional[pulumi.Input[pulumi.InputType['CloudDatabaseManagementCredentialdetailsArgs']]] = None,
                 database_id: Optional[pulumi.Input[str]] = None,
                 enable_management: Optional[pulumi.Input[bool]] = None,
                 management_type: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 private_end_point_id: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 ssl_secret_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Database Management resource in Oracle Cloud Infrastructure Database service.

        Enable / Update / Disable database management for the specified Oracle Database instance.

        Database Management requires `USER_NAME`, `PASSWORD_SECRET_ID` and `PRIVATE_END_POINT_ID`.
        `database.0.database_management_config` is updated to appropriate managementType and managementStatus for the specified Oracle Database instance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test = oci.database.CloudDatabaseManagement("test",
            database_id=oci_database_database["test_database"]["id"],
            management_type=var["database_cloud_database_management_details_management_type"],
            private_end_point_id=var["database_cloud_database_management_details_private_end_point_id"],
            service_name=var["database_cloud_database_management_details_service_name"],
            credentialdetails=oci.database.CloudDatabaseManagementCredentialdetailsArgs(
                user_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                password_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            enable_management=var["database_cloud_database_management_details_enable_management"],
            port=var["cloud_database_management_port"],
            protocol=var["cloud_database_management_protocol"],
            role=var["cloud_database_management_role"],
            ssl_secret_id=oci_vault_secret["test_secret"]["id"])
        ```

        ## Import

        Import is not supported for this resource.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[bool] enable_management: (Updatable) Use this flag to enable/disable database management
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] management_type: (Updatable) Specifies database management type
               enum:
        :param pulumi.Input[int] port: The port used to connect to the database.
        :param pulumi.Input[str] private_end_point_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        :param pulumi.Input[str] protocol: Protocol used by the database connection.
        :param pulumi.Input[str] role: The role of the user that will be connecting to the database.
        :param pulumi.Input[str] service_name: The name of the Oracle Database service that will be used to connect to the database.
        :param pulumi.Input[str] ssl_secret_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CloudDatabaseManagementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Database Management resource in Oracle Cloud Infrastructure Database service.

        Enable / Update / Disable database management for the specified Oracle Database instance.

        Database Management requires `USER_NAME`, `PASSWORD_SECRET_ID` and `PRIVATE_END_POINT_ID`.
        `database.0.database_management_config` is updated to appropriate managementType and managementStatus for the specified Oracle Database instance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test = oci.database.CloudDatabaseManagement("test",
            database_id=oci_database_database["test_database"]["id"],
            management_type=var["database_cloud_database_management_details_management_type"],
            private_end_point_id=var["database_cloud_database_management_details_private_end_point_id"],
            service_name=var["database_cloud_database_management_details_service_name"],
            credentialdetails=oci.database.CloudDatabaseManagementCredentialdetailsArgs(
                user_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                password_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            enable_management=var["database_cloud_database_management_details_enable_management"],
            port=var["cloud_database_management_port"],
            protocol=var["cloud_database_management_protocol"],
            role=var["cloud_database_management_role"],
            ssl_secret_id=oci_vault_secret["test_secret"]["id"])
        ```

        ## Import

        Import is not supported for this resource.

        :param str resource_name: The name of the resource.
        :param CloudDatabaseManagementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudDatabaseManagementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credentialdetails: Optional[pulumi.Input[pulumi.InputType['CloudDatabaseManagementCredentialdetailsArgs']]] = None,
                 database_id: Optional[pulumi.Input[str]] = None,
                 enable_management: Optional[pulumi.Input[bool]] = None,
                 management_type: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 private_end_point_id: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 ssl_secret_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudDatabaseManagementArgs.__new__(CloudDatabaseManagementArgs)

            if credentialdetails is None and not opts.urn:
                raise TypeError("Missing required property 'credentialdetails'")
            __props__.__dict__["credentialdetails"] = credentialdetails
            if database_id is None and not opts.urn:
                raise TypeError("Missing required property 'database_id'")
            __props__.__dict__["database_id"] = database_id
            if enable_management is None and not opts.urn:
                raise TypeError("Missing required property 'enable_management'")
            __props__.__dict__["enable_management"] = enable_management
            if management_type is None and not opts.urn:
                raise TypeError("Missing required property 'management_type'")
            __props__.__dict__["management_type"] = management_type
            __props__.__dict__["port"] = port
            if private_end_point_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_end_point_id'")
            __props__.__dict__["private_end_point_id"] = private_end_point_id
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["role"] = role
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["ssl_secret_id"] = ssl_secret_id
        super(CloudDatabaseManagement, __self__).__init__(
            'oci:Database/cloudDatabaseManagement:CloudDatabaseManagement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            credentialdetails: Optional[pulumi.Input[pulumi.InputType['CloudDatabaseManagementCredentialdetailsArgs']]] = None,
            database_id: Optional[pulumi.Input[str]] = None,
            enable_management: Optional[pulumi.Input[bool]] = None,
            management_type: Optional[pulumi.Input[str]] = None,
            port: Optional[pulumi.Input[int]] = None,
            private_end_point_id: Optional[pulumi.Input[str]] = None,
            protocol: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            service_name: Optional[pulumi.Input[str]] = None,
            ssl_secret_id: Optional[pulumi.Input[str]] = None) -> 'CloudDatabaseManagement':
        """
        Get an existing CloudDatabaseManagement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[bool] enable_management: (Updatable) Use this flag to enable/disable database management
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] management_type: (Updatable) Specifies database management type
               enum:
        :param pulumi.Input[int] port: The port used to connect to the database.
        :param pulumi.Input[str] private_end_point_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        :param pulumi.Input[str] protocol: Protocol used by the database connection.
        :param pulumi.Input[str] role: The role of the user that will be connecting to the database.
        :param pulumi.Input[str] service_name: The name of the Oracle Database service that will be used to connect to the database.
        :param pulumi.Input[str] ssl_secret_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudDatabaseManagementState.__new__(_CloudDatabaseManagementState)

        __props__.__dict__["credentialdetails"] = credentialdetails
        __props__.__dict__["database_id"] = database_id
        __props__.__dict__["enable_management"] = enable_management
        __props__.__dict__["management_type"] = management_type
        __props__.__dict__["port"] = port
        __props__.__dict__["private_end_point_id"] = private_end_point_id
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["role"] = role
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["ssl_secret_id"] = ssl_secret_id
        return CloudDatabaseManagement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def credentialdetails(self) -> pulumi.Output['outputs.CloudDatabaseManagementCredentialdetails']:
        return pulumi.get(self, "credentialdetails")

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> pulumi.Output[str]:
        """
        The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "database_id")

    @property
    @pulumi.getter(name="enableManagement")
    def enable_management(self) -> pulumi.Output[bool]:
        """
        (Updatable) Use this flag to enable/disable database management

        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "enable_management")

    @property
    @pulumi.getter(name="managementType")
    def management_type(self) -> pulumi.Output[str]:
        """
        (Updatable) Specifies database management type
        enum:
        """
        return pulumi.get(self, "management_type")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[int]]:
        """
        The port used to connect to the database.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="privateEndPointId")
    def private_end_point_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint.
        """
        return pulumi.get(self, "private_end_point_id")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[Optional[str]]:
        """
        Protocol used by the database connection.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[Optional[str]]:
        """
        The role of the user that will be connecting to the database.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[str]:
        """
        The name of the Oracle Database service that will be used to connect to the database.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sslSecretId")
    def ssl_secret_id(self) -> pulumi.Output[Optional[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [secret](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
        """
        return pulumi.get(self, "ssl_secret_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSecurityZoneResult',
    'AwaitableGetSecurityZoneResult',
    'get_security_zone',
    'get_security_zone_output',
]

@pulumi.output_type
class GetSecurityZoneResult:
    """
    A collection of values returned by getSecurityZone.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, description=None, display_name=None, freeform_tags=None, id=None, inherited_by_compartments=None, lifecycle_details=None, security_zone_id=None, security_zone_recipe_id=None, security_zone_target_id=None, state=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inherited_by_compartments and not isinstance(inherited_by_compartments, list):
            raise TypeError("Expected argument 'inherited_by_compartments' to be a list")
        pulumi.set(__self__, "inherited_by_compartments", inherited_by_compartments)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if security_zone_id and not isinstance(security_zone_id, str):
            raise TypeError("Expected argument 'security_zone_id' to be a str")
        pulumi.set(__self__, "security_zone_id", security_zone_id)
        if security_zone_recipe_id and not isinstance(security_zone_recipe_id, str):
            raise TypeError("Expected argument 'security_zone_recipe_id' to be a str")
        pulumi.set(__self__, "security_zone_recipe_id", security_zone_recipe_id)
        if security_zone_target_id and not isinstance(security_zone_target_id, str):
            raise TypeError("Expected argument 'security_zone_target_id' to be a str")
        pulumi.set(__self__, "security_zone_target_id", security_zone_target_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment for the security zone
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The security zone's description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The security zone's name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier that is immutable on creation
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inheritedByCompartments")
    def inherited_by_compartments(self) -> Sequence[str]:
        """
        List of inherited compartments
        """
        return pulumi.get(self, "inherited_by_compartments")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, this can be used to provide actionable information for a zone in the `Failed` state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="securityZoneId")
    def security_zone_id(self) -> str:
        return pulumi.get(self, "security_zone_id")

    @property
    @pulumi.getter(name="securityZoneRecipeId")
    def security_zone_recipe_id(self) -> str:
        """
        The OCID of the recipe (`SecurityRecipe`) for the security zone
        """
        return pulumi.get(self, "security_zone_recipe_id")

    @property
    @pulumi.getter(name="securityZoneTargetId")
    def security_zone_target_id(self) -> str:
        """
        The OCID of the target associated with the security zone
        """
        return pulumi.get(self, "security_zone_target_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the security zone
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the security zone was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the security zone was last updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetSecurityZoneResult(GetSecurityZoneResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityZoneResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            id=self.id,
            inherited_by_compartments=self.inherited_by_compartments,
            lifecycle_details=self.lifecycle_details,
            security_zone_id=self.security_zone_id,
            security_zone_recipe_id=self.security_zone_recipe_id,
            security_zone_target_id=self.security_zone_target_id,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_security_zone(security_zone_id: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityZoneResult:
    """
    This data source provides details about a specific Security Zone resource in Oracle Cloud Infrastructure Cloud Guard service.

    Gets a security zone by its identifier. A security zone is associated with a security zone recipe and enforces all security zone policies in the recipe. Any actions in the zone's compartments that violate a policy are denied.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_security_zone = oci.CloudGuard.get_security_zone(security_zone_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str security_zone_id: The unique identifier of the security zone (`SecurityZone`)
    """
    __args__ = dict()
    __args__['securityZoneId'] = security_zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:CloudGuard/getSecurityZone:getSecurityZone', __args__, opts=opts, typ=GetSecurityZoneResult).value

    return AwaitableGetSecurityZoneResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        inherited_by_compartments=__ret__.inherited_by_compartments,
        lifecycle_details=__ret__.lifecycle_details,
        security_zone_id=__ret__.security_zone_id,
        security_zone_recipe_id=__ret__.security_zone_recipe_id,
        security_zone_target_id=__ret__.security_zone_target_id,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_security_zone)
def get_security_zone_output(security_zone_id: Optional[pulumi.Input[str]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSecurityZoneResult]:
    """
    This data source provides details about a specific Security Zone resource in Oracle Cloud Infrastructure Cloud Guard service.

    Gets a security zone by its identifier. A security zone is associated with a security zone recipe and enforces all security zone policies in the recipe. Any actions in the zone's compartments that violate a policy are denied.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_security_zone = oci.CloudGuard.get_security_zone(security_zone_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str security_zone_id: The unique identifier of the security zone (`SecurityZone`)
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetLicenseRecordResult',
    'AwaitableGetLicenseRecordResult',
    'get_license_record',
    'get_license_record_output',
]

@pulumi.output_type
class GetLicenseRecordResult:
    """
    A collection of values returned by getLicenseRecord.
    """
    def __init__(__self__, compartment_id=None, defined_tags=None, display_name=None, expiration_date=None, freeform_tags=None, id=None, is_perpetual=None, is_unlimited=None, license_count=None, license_record_id=None, license_unit=None, product_id=None, product_license=None, product_license_id=None, state=None, support_end_date=None, system_tags=None, time_created=None, time_updated=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if expiration_date and not isinstance(expiration_date, str):
            raise TypeError("Expected argument 'expiration_date' to be a str")
        pulumi.set(__self__, "expiration_date", expiration_date)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_perpetual and not isinstance(is_perpetual, bool):
            raise TypeError("Expected argument 'is_perpetual' to be a bool")
        pulumi.set(__self__, "is_perpetual", is_perpetual)
        if is_unlimited and not isinstance(is_unlimited, bool):
            raise TypeError("Expected argument 'is_unlimited' to be a bool")
        pulumi.set(__self__, "is_unlimited", is_unlimited)
        if license_count and not isinstance(license_count, int):
            raise TypeError("Expected argument 'license_count' to be a int")
        pulumi.set(__self__, "license_count", license_count)
        if license_record_id and not isinstance(license_record_id, str):
            raise TypeError("Expected argument 'license_record_id' to be a str")
        pulumi.set(__self__, "license_record_id", license_record_id)
        if license_unit and not isinstance(license_unit, str):
            raise TypeError("Expected argument 'license_unit' to be a str")
        pulumi.set(__self__, "license_unit", license_unit)
        if product_id and not isinstance(product_id, str):
            raise TypeError("Expected argument 'product_id' to be a str")
        pulumi.set(__self__, "product_id", product_id)
        if product_license and not isinstance(product_license, str):
            raise TypeError("Expected argument 'product_license' to be a str")
        pulumi.set(__self__, "product_license", product_license)
        if product_license_id and not isinstance(product_license_id, str):
            raise TypeError("Expected argument 'product_license_id' to be a str")
        pulumi.set(__self__, "product_license_id", product_license_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if support_end_date and not isinstance(support_end_date, str):
            raise TypeError("Expected argument 'support_end_date' to be a str")
        pulumi.set(__self__, "support_end_date", support_end_date)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) where the license record is created.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The license record display name. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> str:
        """
        The license record end date in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format. Example: `2018-09-12`
        """
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The license record [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isPerpetual")
    def is_perpetual(self) -> bool:
        """
        Specifies if the license record term is perpertual.
        """
        return pulumi.get(self, "is_perpetual")

    @property
    @pulumi.getter(name="isUnlimited")
    def is_unlimited(self) -> bool:
        """
        Specifies if the license count is unlimited.
        """
        return pulumi.get(self, "is_unlimited")

    @property
    @pulumi.getter(name="licenseCount")
    def license_count(self) -> int:
        """
        The number of license units added by the user for the given license record. Default 1
        """
        return pulumi.get(self, "license_count")

    @property
    @pulumi.getter(name="licenseRecordId")
    def license_record_id(self) -> str:
        return pulumi.get(self, "license_record_id")

    @property
    @pulumi.getter(name="licenseUnit")
    def license_unit(self) -> str:
        """
        The product license unit.
        """
        return pulumi.get(self, "license_unit")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        The license record product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productLicense")
    def product_license(self) -> str:
        """
        The product license name with which the license record is associated.
        """
        return pulumi.get(self, "product_license")

    @property
    @pulumi.getter(name="productLicenseId")
    def product_license_id(self) -> str:
        """
        The product license [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) with which the license record is associated.
        """
        return pulumi.get(self, "product_license_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current license record state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="supportEndDate")
    def support_end_date(self) -> str:
        """
        The license record support end date in [RFC 3339](https://tools.ietf.org/html/rfc3339) date format. Example: `2018-09-12`
        """
        return pulumi.get(self, "support_end_date")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the license record was created. An [RFC 3339](https://tools.ietf.org/html/rfc3339)-formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the license record was updated. An [RFC 3339](https://tools.ietf.org/html/rfc3339)-formatted datetime string.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetLicenseRecordResult(GetLicenseRecordResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLicenseRecordResult(
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            expiration_date=self.expiration_date,
            freeform_tags=self.freeform_tags,
            id=self.id,
            is_perpetual=self.is_perpetual,
            is_unlimited=self.is_unlimited,
            license_count=self.license_count,
            license_record_id=self.license_record_id,
            license_unit=self.license_unit,
            product_id=self.product_id,
            product_license=self.product_license,
            product_license_id=self.product_license_id,
            state=self.state,
            support_end_date=self.support_end_date,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_license_record(license_record_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLicenseRecordResult:
    """
    This data source provides details about a specific License Record resource in Oracle Cloud Infrastructure License Manager service.

    Retrieves license record details by the license record ID in a given compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_license_record = oci.LicenseManager.get_license_record(license_record_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str license_record_id: Unique license record identifier.
    """
    __args__ = dict()
    __args__['licenseRecordId'] = license_record_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:LicenseManager/getLicenseRecord:getLicenseRecord', __args__, opts=opts, typ=GetLicenseRecordResult).value

    return AwaitableGetLicenseRecordResult(
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        expiration_date=__ret__.expiration_date,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        is_perpetual=__ret__.is_perpetual,
        is_unlimited=__ret__.is_unlimited,
        license_count=__ret__.license_count,
        license_record_id=__ret__.license_record_id,
        license_unit=__ret__.license_unit,
        product_id=__ret__.product_id,
        product_license=__ret__.product_license,
        product_license_id=__ret__.product_license_id,
        state=__ret__.state,
        support_end_date=__ret__.support_end_date,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_license_record)
def get_license_record_output(license_record_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLicenseRecordResult]:
    """
    This data source provides details about a specific License Record resource in Oracle Cloud Infrastructure License Manager service.

    Retrieves license record details by the license record ID in a given compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_license_record = oci.LicenseManager.get_license_record(license_record_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str license_record_id: Unique license record identifier.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEtlRunsResult',
    'AwaitableGetEtlRunsResult',
    'get_etl_runs',
    'get_etl_runs_output',
]

@pulumi.output_type
class GetEtlRunsResult:
    """
    A collection of values returned by getEtlRuns.
    """
    def __init__(__self__, compartment_id=None, display_name=None, em_warehouse_id=None, etl_run_collections=None, filters=None, id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if em_warehouse_id and not isinstance(em_warehouse_id, str):
            raise TypeError("Expected argument 'em_warehouse_id' to be a str")
        pulumi.set(__self__, "em_warehouse_id", em_warehouse_id)
        if etl_run_collections and not isinstance(etl_run_collections, list):
            raise TypeError("Expected argument 'etl_run_collections' to be a list")
        pulumi.set(__self__, "etl_run_collections", etl_run_collections)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        """
        Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The name of the ETLRun.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="emWarehouseId")
    def em_warehouse_id(self) -> str:
        return pulumi.get(self, "em_warehouse_id")

    @property
    @pulumi.getter(name="etlRunCollections")
    def etl_run_collections(self) -> Sequence['outputs.GetEtlRunsEtlRunCollectionResult']:
        """
        The list of etl_run_collection.
        """
        return pulumi.get(self, "etl_run_collections")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetEtlRunsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetEtlRunsResult(GetEtlRunsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEtlRunsResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            em_warehouse_id=self.em_warehouse_id,
            etl_run_collections=self.etl_run_collections,
            filters=self.filters,
            id=self.id)


def get_etl_runs(compartment_id: Optional[str] = None,
                 display_name: Optional[str] = None,
                 em_warehouse_id: Optional[str] = None,
                 filters: Optional[Sequence[pulumi.InputType['GetEtlRunsFilterArgs']]] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEtlRunsResult:
    """
    This data source provides the list of Em Warehouse Etl Runs in Oracle Cloud Infrastructure Em Warehouse service.

    Gets a list of runs of an EmWarehouseResource by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_em_warehouse_etl_runs = oci.EmWarehouse.get_etl_runs(em_warehouse_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str em_warehouse_id: unique EmWarehouse identifier
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['emWarehouseId'] = em_warehouse_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:EmWarehouse/getEtlRuns:getEtlRuns', __args__, opts=opts, typ=GetEtlRunsResult).value

    return AwaitableGetEtlRunsResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        em_warehouse_id=__ret__.em_warehouse_id,
        etl_run_collections=__ret__.etl_run_collections,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_etl_runs)
def get_etl_runs_output(compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                        display_name: Optional[pulumi.Input[Optional[str]]] = None,
                        em_warehouse_id: Optional[pulumi.Input[str]] = None,
                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetEtlRunsFilterArgs']]]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEtlRunsResult]:
    """
    This data source provides the list of Em Warehouse Etl Runs in Oracle Cloud Infrastructure Em Warehouse service.

    Gets a list of runs of an EmWarehouseResource by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_em_warehouse_etl_runs = oci.EmWarehouse.get_etl_runs(em_warehouse_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str em_warehouse_id: unique EmWarehouse identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetLimitDefinitionsResult',
    'AwaitableGetLimitDefinitionsResult',
    'get_limit_definitions',
    'get_limit_definitions_output',
]

@pulumi.output_type
class GetLimitDefinitionsResult:
    """
    A collection of values returned by getLimitDefinitions.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, limit_definitions=None, name=None, service_name=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit_definitions and not isinstance(limit_definitions, list):
            raise TypeError("Expected argument 'limit_definitions' to be a list")
        pulumi.set(__self__, "limit_definitions", limit_definitions)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetLimitDefinitionsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="limitDefinitions")
    def limit_definitions(self) -> Sequence['outputs.GetLimitDefinitionsLimitDefinitionResult']:
        """
        The list of limit_definitions.
        """
        return pulumi.get(self, "limit_definitions")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The resource limit name. To be used for writing policies (in case of quotas) or other programmatic calls.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[str]:
        """
        The service name of the limit.
        """
        return pulumi.get(self, "service_name")


class AwaitableGetLimitDefinitionsResult(GetLimitDefinitionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLimitDefinitionsResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            limit_definitions=self.limit_definitions,
            name=self.name,
            service_name=self.service_name)


def get_limit_definitions(compartment_id: Optional[str] = None,
                          filters: Optional[Sequence[pulumi.InputType['GetLimitDefinitionsFilterArgs']]] = None,
                          name: Optional[str] = None,
                          service_name: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLimitDefinitionsResult:
    """
    This data source provides the list of Limit Definitions in Oracle Cloud Infrastructure Limits service.

    Includes a list of resource limits that are currently supported.
    If the 'areQuotasSupported' property is true, you can create quota policies on top of this limit at the
    compartment level.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_limit_definitions = oci.Limits.get_limit_definitions(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        service_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the parent compartment (remember that the tenancy is simply the root compartment).
    :param str name: Optional field, filter for a specific resource limit.
    :param str service_name: The target service name.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Limits/getLimitDefinitions:getLimitDefinitions', __args__, opts=opts, typ=GetLimitDefinitionsResult).value

    return AwaitableGetLimitDefinitionsResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        limit_definitions=__ret__.limit_definitions,
        name=__ret__.name,
        service_name=__ret__.service_name)


@_utilities.lift_output_func(get_limit_definitions)
def get_limit_definitions_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                 filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetLimitDefinitionsFilterArgs']]]]] = None,
                                 name: Optional[pulumi.Input[Optional[str]]] = None,
                                 service_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLimitDefinitionsResult]:
    """
    This data source provides the list of Limit Definitions in Oracle Cloud Infrastructure Limits service.

    Includes a list of resource limits that are currently supported.
    If the 'areQuotasSupported' property is true, you can create quota policies on top of this limit at the
    compartment level.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_limit_definitions = oci.Limits.get_limit_definitions(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        service_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the parent compartment (remember that the tenancy is simply the root compartment).
    :param str name: Optional field, filter for a specific resource limit.
    :param str service_name: The target service name.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .discovery_job import *
from .get_discovery_job import *
from .get_discovery_job_logs import *
from .get_discovery_jobs import *
from .get_monitored_resource import *
from .monitored_resource import *
from .monitored_resources_associate_monitored_resource import *
from .monitored_resources_list_member import *
from .monitored_resources_search import *
from .monitored_resources_search_association import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetNamespaceResult',
    'AwaitableGetNamespaceResult',
    'get_namespace',
    'get_namespace_output',
]

@pulumi.output_type
class GetNamespaceResult:
    """
    A collection of values returned by getNamespace.
    """
    def __init__(__self__, compartment_id=None, id=None, is_onboarded=None, namespace=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_onboarded and not isinstance(is_onboarded, bool):
            raise TypeError("Expected argument 'is_onboarded' to be a bool")
        pulumi.set(__self__, "is_onboarded", is_onboarded)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The is the tenancy ID
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOnboarded")
    def is_onboarded(self) -> bool:
        """
        This indicates if the tenancy is onboarded to Logging Analytics
        """
        return pulumi.get(self, "is_onboarded")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        This is the namespace name of a tenancy
        """
        return pulumi.get(self, "namespace")


class AwaitableGetNamespaceResult(GetNamespaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNamespaceResult(
            compartment_id=self.compartment_id,
            id=self.id,
            is_onboarded=self.is_onboarded,
            namespace=self.namespace)


def get_namespace(namespace: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNamespaceResult:
    """
    This data source provides details about a specific Namespace resource in Oracle Cloud Infrastructure Log Analytics service.

    This API gets the namespace details of a tenancy already onboarded in Logging Analytics Application

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_namespace = oci.LogAnalytics.get_namespace(namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str namespace: The Logging Analytics namespace used for the request.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:LogAnalytics/getNamespace:getNamespace', __args__, opts=opts, typ=GetNamespaceResult).value

    return AwaitableGetNamespaceResult(
        compartment_id=__ret__.compartment_id,
        id=__ret__.id,
        is_onboarded=__ret__.is_onboarded,
        namespace=__ret__.namespace)


@_utilities.lift_output_func(get_namespace)
def get_namespace_output(namespace: Optional[pulumi.Input[str]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNamespaceResult]:
    """
    This data source provides details about a specific Namespace resource in Oracle Cloud Infrastructure Log Analytics service.

    This API gets the namespace details of a tenancy already onboarded in Logging Analytics Application

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_namespace = oci.LogAnalytics.get_namespace(namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str namespace: The Logging Analytics namespace used for the request.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSdmMaskingPolicyDifferencesResult',
    'AwaitableGetSdmMaskingPolicyDifferencesResult',
    'get_sdm_masking_policy_differences',
    'get_sdm_masking_policy_differences_output',
]

@pulumi.output_type
class GetSdmMaskingPolicyDifferencesResult:
    """
    A collection of values returned by getSdmMaskingPolicyDifferences.
    """
    def __init__(__self__, compartment_id=None, compartment_id_in_subtree=None, difference_access_level=None, display_name=None, filters=None, id=None, masking_policy_id=None, sdm_masking_policy_difference_collections=None, sensitive_data_model_id=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if difference_access_level and not isinstance(difference_access_level, str):
            raise TypeError("Expected argument 'difference_access_level' to be a str")
        pulumi.set(__self__, "difference_access_level", difference_access_level)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if masking_policy_id and not isinstance(masking_policy_id, str):
            raise TypeError("Expected argument 'masking_policy_id' to be a str")
        pulumi.set(__self__, "masking_policy_id", masking_policy_id)
        if sdm_masking_policy_difference_collections and not isinstance(sdm_masking_policy_difference_collections, list):
            raise TypeError("Expected argument 'sdm_masking_policy_difference_collections' to be a list")
        pulumi.set(__self__, "sdm_masking_policy_difference_collections", sdm_masking_policy_difference_collections)
        if sensitive_data_model_id and not isinstance(sensitive_data_model_id, str):
            raise TypeError("Expected argument 'sensitive_data_model_id' to be a str")
        pulumi.set(__self__, "sensitive_data_model_id", sensitive_data_model_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains the SDM masking policy difference.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter(name="differenceAccessLevel")
    def difference_access_level(self) -> Optional[str]:
        return pulumi.get(self, "difference_access_level")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The display name of the SDM masking policy difference.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetSdmMaskingPolicyDifferencesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="maskingPolicyId")
    def masking_policy_id(self) -> Optional[str]:
        """
        The OCID of the masking policy associated with the SDM masking policy difference.
        """
        return pulumi.get(self, "masking_policy_id")

    @property
    @pulumi.getter(name="sdmMaskingPolicyDifferenceCollections")
    def sdm_masking_policy_difference_collections(self) -> Sequence['outputs.GetSdmMaskingPolicyDifferencesSdmMaskingPolicyDifferenceCollectionResult']:
        """
        The list of sdm_masking_policy_difference_collection.
        """
        return pulumi.get(self, "sdm_masking_policy_difference_collections")

    @property
    @pulumi.getter(name="sensitiveDataModelId")
    def sensitive_data_model_id(self) -> Optional[str]:
        """
        The OCID of the sensitive data model associated with the SDM masking policy difference.
        """
        return pulumi.get(self, "sensitive_data_model_id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the SDM masking policy difference.
        """
        return pulumi.get(self, "state")


class AwaitableGetSdmMaskingPolicyDifferencesResult(GetSdmMaskingPolicyDifferencesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSdmMaskingPolicyDifferencesResult(
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            difference_access_level=self.difference_access_level,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            masking_policy_id=self.masking_policy_id,
            sdm_masking_policy_difference_collections=self.sdm_masking_policy_difference_collections,
            sensitive_data_model_id=self.sensitive_data_model_id,
            state=self.state)


def get_sdm_masking_policy_differences(compartment_id: Optional[str] = None,
                                       compartment_id_in_subtree: Optional[bool] = None,
                                       difference_access_level: Optional[str] = None,
                                       display_name: Optional[str] = None,
                                       filters: Optional[Sequence[pulumi.InputType['GetSdmMaskingPolicyDifferencesFilterArgs']]] = None,
                                       masking_policy_id: Optional[str] = None,
                                       sensitive_data_model_id: Optional[str] = None,
                                       state: Optional[str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSdmMaskingPolicyDifferencesResult:
    """
    This data source provides the list of Sdm Masking Policy Differences in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of SDM and masking policy difference resources based on the specified query parameters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_sdm_masking_policy_differences = oci.DataSafe.get_sdm_masking_policy_differences(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        difference_access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        masking_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sensitive_data_model_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str difference_access_level: Valid value is ACCESSIBLE. Default is ACCESSIBLE. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment).
    :param str display_name: A filter to return only resources that match the specified display name.
    :param str masking_policy_id: A filter to return only the resources that match the specified masking policy OCID.
    :param str sensitive_data_model_id: A filter to return only the resources that match the specified sensitive data model OCID.
    :param str state: A filter to return only the resources that match the specified lifecycle states.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['differenceAccessLevel'] = difference_access_level
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['maskingPolicyId'] = masking_policy_id
    __args__['sensitiveDataModelId'] = sensitive_data_model_id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getSdmMaskingPolicyDifferences:getSdmMaskingPolicyDifferences', __args__, opts=opts, typ=GetSdmMaskingPolicyDifferencesResult).value

    return AwaitableGetSdmMaskingPolicyDifferencesResult(
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        difference_access_level=__ret__.difference_access_level,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        masking_policy_id=__ret__.masking_policy_id,
        sdm_masking_policy_difference_collections=__ret__.sdm_masking_policy_difference_collections,
        sensitive_data_model_id=__ret__.sensitive_data_model_id,
        state=__ret__.state)


@_utilities.lift_output_func(get_sdm_masking_policy_differences)
def get_sdm_masking_policy_differences_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                              compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                                              difference_access_level: Optional[pulumi.Input[Optional[str]]] = None,
                                              display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                              filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetSdmMaskingPolicyDifferencesFilterArgs']]]]] = None,
                                              masking_policy_id: Optional[pulumi.Input[Optional[str]]] = None,
                                              sensitive_data_model_id: Optional[pulumi.Input[Optional[str]]] = None,
                                              state: Optional[pulumi.Input[Optional[str]]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSdmMaskingPolicyDifferencesResult]:
    """
    This data source provides the list of Sdm Masking Policy Differences in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of SDM and masking policy difference resources based on the specified query parameters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_sdm_masking_policy_differences = oci.DataSafe.get_sdm_masking_policy_differences(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        difference_access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        masking_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sensitive_data_model_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str difference_access_level: Valid value is ACCESSIBLE. Default is ACCESSIBLE. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment).
    :param str display_name: A filter to return only resources that match the specified display name.
    :param str masking_policy_id: A filter to return only the resources that match the specified masking policy OCID.
    :param str sensitive_data_model_id: A filter to return only the resources that match the specified sensitive data model OCID.
    :param str state: A filter to return only the resources that match the specified lifecycle states.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RecommendationArgs', 'Recommendation']

@pulumi.input_type
class RecommendationArgs:
    def __init__(__self__, *,
                 recommendation_id: pulumi.Input[str],
                 status: pulumi.Input[str],
                 time_status_end: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Recommendation resource.
        :param pulumi.Input[str] recommendation_id: The unique OCID associated with the recommendation.
        :param pulumi.Input[str] status: (Updatable) The status of the recommendation.
        :param pulumi.Input[str] time_status_end: (Updatable) The date and time the current status will change. The format is defined by RFC3339.
               
               For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "recommendation_id", recommendation_id)
        pulumi.set(__self__, "status", status)
        if time_status_end is not None:
            pulumi.set(__self__, "time_status_end", time_status_end)

    @property
    @pulumi.getter(name="recommendationId")
    def recommendation_id(self) -> pulumi.Input[str]:
        """
        The unique OCID associated with the recommendation.
        """
        return pulumi.get(self, "recommendation_id")

    @recommendation_id.setter
    def recommendation_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "recommendation_id", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[str]:
        """
        (Updatable) The status of the recommendation.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="timeStatusEnd")
    def time_status_end(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The date and time the current status will change. The format is defined by RFC3339.

        For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "time_status_end")

    @time_status_end.setter
    def time_status_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_status_end", value)


@pulumi.input_type
class _RecommendationState:
    def __init__(__self__, *,
                 category_id: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 estimated_cost_saving: Optional[pulumi.Input[float]] = None,
                 extended_metadata: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 importance: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 recommendation_id: Optional[pulumi.Input[str]] = None,
                 resource_counts: Optional[pulumi.Input[Sequence[pulumi.Input['RecommendationResourceCountArgs']]]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 supported_levels: Optional[pulumi.Input[Sequence[pulumi.Input['RecommendationSupportedLevelArgs']]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_status_begin: Optional[pulumi.Input[str]] = None,
                 time_status_end: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Recommendation resources.
        :param pulumi.Input[str] category_id: The unique OCID associated with the category.
        :param pulumi.Input[str] compartment_id: The OCID of the tenancy. The tenancy is the root compartment.
        :param pulumi.Input[str] description: Text describing the recommendation.
        :param pulumi.Input[float] estimated_cost_saving: The estimated cost savings, in dollars, for the recommendation.
        :param pulumi.Input[Mapping[str, Any]] extended_metadata: Additional metadata key/value pairs for the recommendation.
        :param pulumi.Input[str] importance: The level of importance assigned to the recommendation.
        :param pulumi.Input[str] name: The name of the profile level.
        :param pulumi.Input[str] recommendation_id: The unique OCID associated with the recommendation.
        :param pulumi.Input[Sequence[pulumi.Input['RecommendationResourceCountArgs']]] resource_counts: An array of `ResourceCount` objects grouped by the status of the resource actions.
        :param pulumi.Input[str] state: The recommendation's current state.
        :param pulumi.Input[str] status: (Updatable) The status of the recommendation.
        :param pulumi.Input[Sequence[pulumi.Input['RecommendationSupportedLevelArgs']]] supported_levels: Optional. The profile levels supported by a recommendation. For example, profile level values could be `Low`, `Medium`, and `High`. Not all recommendations support this field.
        :param pulumi.Input[str] time_created: The date and time the recommendation details were created, in the format defined by RFC3339.
        :param pulumi.Input[str] time_status_begin: The date and time that the recommendation entered its current status. The format is defined by RFC3339.
        :param pulumi.Input[str] time_status_end: (Updatable) The date and time the current status will change. The format is defined by RFC3339.
               
               For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_updated: The date and time the recommendation details were last updated, in the format defined by RFC3339.
        """
        if category_id is not None:
            pulumi.set(__self__, "category_id", category_id)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if estimated_cost_saving is not None:
            pulumi.set(__self__, "estimated_cost_saving", estimated_cost_saving)
        if extended_metadata is not None:
            pulumi.set(__self__, "extended_metadata", extended_metadata)
        if importance is not None:
            pulumi.set(__self__, "importance", importance)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if recommendation_id is not None:
            pulumi.set(__self__, "recommendation_id", recommendation_id)
        if resource_counts is not None:
            pulumi.set(__self__, "resource_counts", resource_counts)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if supported_levels is not None:
            pulumi.set(__self__, "supported_levels", supported_levels)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_status_begin is not None:
            pulumi.set(__self__, "time_status_begin", time_status_begin)
        if time_status_end is not None:
            pulumi.set(__self__, "time_status_end", time_status_end)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="categoryId")
    def category_id(self) -> Optional[pulumi.Input[str]]:
        """
        The unique OCID associated with the category.
        """
        return pulumi.get(self, "category_id")

    @category_id.setter
    def category_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "category_id", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the tenancy. The tenancy is the root compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Text describing the recommendation.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="estimatedCostSaving")
    def estimated_cost_saving(self) -> Optional[pulumi.Input[float]]:
        """
        The estimated cost savings, in dollars, for the recommendation.
        """
        return pulumi.get(self, "estimated_cost_saving")

    @estimated_cost_saving.setter
    def estimated_cost_saving(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "estimated_cost_saving", value)

    @property
    @pulumi.getter(name="extendedMetadata")
    def extended_metadata(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional metadata key/value pairs for the recommendation.
        """
        return pulumi.get(self, "extended_metadata")

    @extended_metadata.setter
    def extended_metadata(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "extended_metadata", value)

    @property
    @pulumi.getter
    def importance(self) -> Optional[pulumi.Input[str]]:
        """
        The level of importance assigned to the recommendation.
        """
        return pulumi.get(self, "importance")

    @importance.setter
    def importance(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "importance", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the profile level.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="recommendationId")
    def recommendation_id(self) -> Optional[pulumi.Input[str]]:
        """
        The unique OCID associated with the recommendation.
        """
        return pulumi.get(self, "recommendation_id")

    @recommendation_id.setter
    def recommendation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recommendation_id", value)

    @property
    @pulumi.getter(name="resourceCounts")
    def resource_counts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecommendationResourceCountArgs']]]]:
        """
        An array of `ResourceCount` objects grouped by the status of the resource actions.
        """
        return pulumi.get(self, "resource_counts")

    @resource_counts.setter
    def resource_counts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecommendationResourceCountArgs']]]]):
        pulumi.set(self, "resource_counts", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The recommendation's current state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The status of the recommendation.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="supportedLevels")
    def supported_levels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecommendationSupportedLevelArgs']]]]:
        """
        Optional. The profile levels supported by a recommendation. For example, profile level values could be `Low`, `Medium`, and `High`. Not all recommendations support this field.
        """
        return pulumi.get(self, "supported_levels")

    @supported_levels.setter
    def supported_levels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecommendationSupportedLevelArgs']]]]):
        pulumi.set(self, "supported_levels", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the recommendation details were created, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeStatusBegin")
    def time_status_begin(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time that the recommendation entered its current status. The format is defined by RFC3339.
        """
        return pulumi.get(self, "time_status_begin")

    @time_status_begin.setter
    def time_status_begin(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_status_begin", value)

    @property
    @pulumi.getter(name="timeStatusEnd")
    def time_status_end(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The date and time the current status will change. The format is defined by RFC3339.

        For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "time_status_end")

    @time_status_end.setter
    def time_status_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_status_end", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the recommendation details were last updated, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class Recommendation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 recommendation_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 time_status_end: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Recommendation resource in Oracle Cloud Infrastructure Optimizer service.

        Updates the recommendation that corresponds to the specified OCID.
        Use this operation to implement the following actions:

          * Postpone recommendation
          * Dismiss recommendation
          * Reactivate recommendation

        ## Import

        Recommendations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Optimizer/recommendation:Recommendation test_recommendation "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] recommendation_id: The unique OCID associated with the recommendation.
        :param pulumi.Input[str] status: (Updatable) The status of the recommendation.
        :param pulumi.Input[str] time_status_end: (Updatable) The date and time the current status will change. The format is defined by RFC3339.
               
               For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RecommendationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Recommendation resource in Oracle Cloud Infrastructure Optimizer service.

        Updates the recommendation that corresponds to the specified OCID.
        Use this operation to implement the following actions:

          * Postpone recommendation
          * Dismiss recommendation
          * Reactivate recommendation

        ## Import

        Recommendations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Optimizer/recommendation:Recommendation test_recommendation "id"
        ```

        :param str resource_name: The name of the resource.
        :param RecommendationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RecommendationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 recommendation_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 time_status_end: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RecommendationArgs.__new__(RecommendationArgs)

            if recommendation_id is None and not opts.urn:
                raise TypeError("Missing required property 'recommendation_id'")
            __props__.__dict__["recommendation_id"] = recommendation_id
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            __props__.__dict__["time_status_end"] = time_status_end
            __props__.__dict__["category_id"] = None
            __props__.__dict__["compartment_id"] = None
            __props__.__dict__["description"] = None
            __props__.__dict__["estimated_cost_saving"] = None
            __props__.__dict__["extended_metadata"] = None
            __props__.__dict__["importance"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["resource_counts"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["supported_levels"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_status_begin"] = None
            __props__.__dict__["time_updated"] = None
        super(Recommendation, __self__).__init__(
            'oci:Optimizer/recommendation:Recommendation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            category_id: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            estimated_cost_saving: Optional[pulumi.Input[float]] = None,
            extended_metadata: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            importance: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            recommendation_id: Optional[pulumi.Input[str]] = None,
            resource_counts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecommendationResourceCountArgs']]]]] = None,
            state: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            supported_levels: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecommendationSupportedLevelArgs']]]]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_status_begin: Optional[pulumi.Input[str]] = None,
            time_status_end: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'Recommendation':
        """
        Get an existing Recommendation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] category_id: The unique OCID associated with the category.
        :param pulumi.Input[str] compartment_id: The OCID of the tenancy. The tenancy is the root compartment.
        :param pulumi.Input[str] description: Text describing the recommendation.
        :param pulumi.Input[float] estimated_cost_saving: The estimated cost savings, in dollars, for the recommendation.
        :param pulumi.Input[Mapping[str, Any]] extended_metadata: Additional metadata key/value pairs for the recommendation.
        :param pulumi.Input[str] importance: The level of importance assigned to the recommendation.
        :param pulumi.Input[str] name: The name of the profile level.
        :param pulumi.Input[str] recommendation_id: The unique OCID associated with the recommendation.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecommendationResourceCountArgs']]]] resource_counts: An array of `ResourceCount` objects grouped by the status of the resource actions.
        :param pulumi.Input[str] state: The recommendation's current state.
        :param pulumi.Input[str] status: (Updatable) The status of the recommendation.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecommendationSupportedLevelArgs']]]] supported_levels: Optional. The profile levels supported by a recommendation. For example, profile level values could be `Low`, `Medium`, and `High`. Not all recommendations support this field.
        :param pulumi.Input[str] time_created: The date and time the recommendation details were created, in the format defined by RFC3339.
        :param pulumi.Input[str] time_status_begin: The date and time that the recommendation entered its current status. The format is defined by RFC3339.
        :param pulumi.Input[str] time_status_end: (Updatable) The date and time the current status will change. The format is defined by RFC3339.
               
               For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_updated: The date and time the recommendation details were last updated, in the format defined by RFC3339.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RecommendationState.__new__(_RecommendationState)

        __props__.__dict__["category_id"] = category_id
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["description"] = description
        __props__.__dict__["estimated_cost_saving"] = estimated_cost_saving
        __props__.__dict__["extended_metadata"] = extended_metadata
        __props__.__dict__["importance"] = importance
        __props__.__dict__["name"] = name
        __props__.__dict__["recommendation_id"] = recommendation_id
        __props__.__dict__["resource_counts"] = resource_counts
        __props__.__dict__["state"] = state
        __props__.__dict__["status"] = status
        __props__.__dict__["supported_levels"] = supported_levels
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_status_begin"] = time_status_begin
        __props__.__dict__["time_status_end"] = time_status_end
        __props__.__dict__["time_updated"] = time_updated
        return Recommendation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="categoryId")
    def category_id(self) -> pulumi.Output[str]:
        """
        The unique OCID associated with the category.
        """
        return pulumi.get(self, "category_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the tenancy. The tenancy is the root compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Text describing the recommendation.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="estimatedCostSaving")
    def estimated_cost_saving(self) -> pulumi.Output[float]:
        """
        The estimated cost savings, in dollars, for the recommendation.
        """
        return pulumi.get(self, "estimated_cost_saving")

    @property
    @pulumi.getter(name="extendedMetadata")
    def extended_metadata(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Additional metadata key/value pairs for the recommendation.
        """
        return pulumi.get(self, "extended_metadata")

    @property
    @pulumi.getter
    def importance(self) -> pulumi.Output[str]:
        """
        The level of importance assigned to the recommendation.
        """
        return pulumi.get(self, "importance")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the profile level.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="recommendationId")
    def recommendation_id(self) -> pulumi.Output[str]:
        """
        The unique OCID associated with the recommendation.
        """
        return pulumi.get(self, "recommendation_id")

    @property
    @pulumi.getter(name="resourceCounts")
    def resource_counts(self) -> pulumi.Output[Sequence['outputs.RecommendationResourceCount']]:
        """
        An array of `ResourceCount` objects grouped by the status of the resource actions.
        """
        return pulumi.get(self, "resource_counts")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The recommendation's current state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        (Updatable) The status of the recommendation.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportedLevels")
    def supported_levels(self) -> pulumi.Output[Sequence['outputs.RecommendationSupportedLevel']]:
        """
        Optional. The profile levels supported by a recommendation. For example, profile level values could be `Low`, `Medium`, and `High`. Not all recommendations support this field.
        """
        return pulumi.get(self, "supported_levels")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the recommendation details were created, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeStatusBegin")
    def time_status_begin(self) -> pulumi.Output[str]:
        """
        The date and time that the recommendation entered its current status. The format is defined by RFC3339.
        """
        return pulumi.get(self, "time_status_begin")

    @property
    @pulumi.getter(name="timeStatusEnd")
    def time_status_end(self) -> pulumi.Output[str]:
        """
        (Updatable) The date and time the current status will change. The format is defined by RFC3339.

        For example, "The current `postponed` status of the recommendation will end and change to `pending` on this date and time."


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "time_status_end")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The date and time the recommendation details were last updated, in the format defined by RFC3339.
        """
        return pulumi.get(self, "time_updated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAvailabilityDomainsResult',
    'AwaitableGetAvailabilityDomainsResult',
    'get_availability_domains',
    'get_availability_domains_output',
]

@pulumi.output_type
class GetAvailabilityDomainsResult:
    """
    A collection of values returned by getAvailabilityDomains.
    """
    def __init__(__self__, availability_domains=None, compartment_id=None, filters=None, id=None):
        if availability_domains and not isinstance(availability_domains, list):
            raise TypeError("Expected argument 'availability_domains' to be a list")
        pulumi.set(__self__, "availability_domains", availability_domains)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="availabilityDomains")
    def availability_domains(self) -> Sequence['outputs.GetAvailabilityDomainsAvailabilityDomainResult']:
        """
        The list of availability_domains.
        """
        return pulumi.get(self, "availability_domains")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the tenancy.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAvailabilityDomainsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetAvailabilityDomainsResult(GetAvailabilityDomainsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAvailabilityDomainsResult(
            availability_domains=self.availability_domains,
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id)


def get_availability_domains(compartment_id: Optional[str] = None,
                             filters: Optional[Sequence[pulumi.InputType['GetAvailabilityDomainsFilterArgs']]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAvailabilityDomainsResult:
    """
    This data source provides the list of Availability Domains in Oracle Cloud Infrastructure Identity service.

    Lists the availability domains in your tenancy. Specify the OCID of either the tenancy or another
    of your compartments as the value for the compartment ID (remember that the tenancy is simply the root compartment).
    See [Where to Get the Tenancy's OCID and User's OCID](https://docs.cloud.oracle.com/iaas/Content/API/Concepts/apisigningkey.htm#five).
    Note that the order of the results returned can change if availability domains are added or removed; therefore, do not
    create a dependency on the list order.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_availability_domains = oci.Identity.get_availability_domains(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getAvailabilityDomains:getAvailabilityDomains', __args__, opts=opts, typ=GetAvailabilityDomainsResult).value

    return AwaitableGetAvailabilityDomainsResult(
        availability_domains=__ret__.availability_domains,
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_availability_domains)
def get_availability_domains_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAvailabilityDomainsFilterArgs']]]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAvailabilityDomainsResult]:
    """
    This data source provides the list of Availability Domains in Oracle Cloud Infrastructure Identity service.

    Lists the availability domains in your tenancy. Specify the OCID of either the tenancy or another
    of your compartments as the value for the compartment ID (remember that the tenancy is simply the root compartment).
    See [Where to Get the Tenancy's OCID and User's OCID](https://docs.cloud.oracle.com/iaas/Content/API/Concepts/apisigningkey.htm#five).
    Note that the order of the results returned can change if availability domains are added or removed; therefore, do not
    create a dependency on the list order.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_availability_domains = oci.Identity.get_availability_domains(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetReplicaResult',
    'AwaitableGetReplicaResult',
    'get_replica',
    'get_replica_output',
]

@pulumi.output_type
class GetReplicaResult:
    """
    A collection of values returned by getReplica.
    """
    def __init__(__self__, availability_domain=None, compartment_id=None, db_system_id=None, defined_tags=None, description=None, display_name=None, fault_domain=None, freeform_tags=None, id=None, ip_address=None, is_delete_protected=None, lifecycle_details=None, mysql_version=None, port=None, port_x=None, replica_id=None, state=None, time_created=None, time_updated=None):
        if availability_domain and not isinstance(availability_domain, str):
            raise TypeError("Expected argument 'availability_domain' to be a str")
        pulumi.set(__self__, "availability_domain", availability_domain)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if db_system_id and not isinstance(db_system_id, str):
            raise TypeError("Expected argument 'db_system_id' to be a str")
        pulumi.set(__self__, "db_system_id", db_system_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if fault_domain and not isinstance(fault_domain, str):
            raise TypeError("Expected argument 'fault_domain' to be a str")
        pulumi.set(__self__, "fault_domain", fault_domain)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if is_delete_protected and not isinstance(is_delete_protected, bool):
            raise TypeError("Expected argument 'is_delete_protected' to be a bool")
        pulumi.set(__self__, "is_delete_protected", is_delete_protected)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if mysql_version and not isinstance(mysql_version, str):
            raise TypeError("Expected argument 'mysql_version' to be a str")
        pulumi.set(__self__, "mysql_version", mysql_version)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if port_x and not isinstance(port_x, int):
            raise TypeError("Expected argument 'port_x' to be a int")
        pulumi.set(__self__, "port_x", port_x)
        if replica_id and not isinstance(replica_id, str):
            raise TypeError("Expected argument 'replica_id' to be a str")
        pulumi.set(__self__, "replica_id", replica_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="availabilityDomain")
    def availability_domain(self) -> str:
        """
        The name of the Availability Domain the read replica is located in.
        """
        return pulumi.get(self, "availability_domain")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains the read replica.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dbSystemId")
    def db_system_id(self) -> str:
        """
        The OCID of the DB System the read replica is associated with.
        """
        return pulumi.get(self, "db_system_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        User provided description of the read replica.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The user-friendly name for the read replica. It does not have to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="faultDomain")
    def fault_domain(self) -> str:
        """
        The name of the Fault Domain the read replica is located in.
        """
        return pulumi.get(self, "fault_domain")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the read replica.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        The IP address the read replica is configured to listen on.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="isDeleteProtected")
    def is_delete_protected(self) -> bool:
        """
        Specifies whether the read replica can be deleted. Set to true to prevent deletion, false (default) to allow. Note that if a read replica is delete protected it also prevents the entire DB System from being deleted. If the DB System is delete protected, read replicas can still be deleted individually if they are not delete  protected themselves.
        """
        return pulumi.get(self, "is_delete_protected")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the state of the read replica.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="mysqlVersion")
    def mysql_version(self) -> str:
        """
        The MySQL version used by the read replica.
        """
        return pulumi.get(self, "mysql_version")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        The port the read replica is configured to listen on.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="portX")
    def port_x(self) -> int:
        """
        The TCP network port on which X Plugin listens for connections. This is the X Plugin equivalent of port.
        """
        return pulumi.get(self, "port_x")

    @property
    @pulumi.getter(name="replicaId")
    def replica_id(self) -> str:
        return pulumi.get(self, "replica_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The state of the read replica.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the read replica was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the read replica was last updated, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetReplicaResult(GetReplicaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReplicaResult(
            availability_domain=self.availability_domain,
            compartment_id=self.compartment_id,
            db_system_id=self.db_system_id,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            fault_domain=self.fault_domain,
            freeform_tags=self.freeform_tags,
            id=self.id,
            ip_address=self.ip_address,
            is_delete_protected=self.is_delete_protected,
            lifecycle_details=self.lifecycle_details,
            mysql_version=self.mysql_version,
            port=self.port,
            port_x=self.port_x,
            replica_id=self.replica_id,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_replica(replica_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReplicaResult:
    """
    This data source provides details about a specific Replica resource in Oracle Cloud Infrastructure MySQL Database service.

    Gets the full details of the specified read replica.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_replica = oci.Mysql.get_replica(replica_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str replica_id: The Replica [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['replicaId'] = replica_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Mysql/getReplica:getReplica', __args__, opts=opts, typ=GetReplicaResult).value

    return AwaitableGetReplicaResult(
        availability_domain=__ret__.availability_domain,
        compartment_id=__ret__.compartment_id,
        db_system_id=__ret__.db_system_id,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        fault_domain=__ret__.fault_domain,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        ip_address=__ret__.ip_address,
        is_delete_protected=__ret__.is_delete_protected,
        lifecycle_details=__ret__.lifecycle_details,
        mysql_version=__ret__.mysql_version,
        port=__ret__.port,
        port_x=__ret__.port_x,
        replica_id=__ret__.replica_id,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_replica)
def get_replica_output(replica_id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetReplicaResult]:
    """
    This data source provides details about a specific Replica resource in Oracle Cloud Infrastructure MySQL Database service.

    Gets the full details of the specified read replica.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_replica = oci.Mysql.get_replica(replica_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str replica_id: The Replica [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...
